@@ -17,7 +17,7 @@ use ghost_actor::dependencies::tracing;
 use ghost_actor::dependencies::tracing_futures::Instrument;
 pub use spawn::*;
 pub use test::stub_network;
-pub use test::HolochainP2pCellFixturator;
+pub use test::HolochainP2pDnaFixturator;
 
 pub use kitsune_p2p;
 
@@ -25,27 +25,20 @@ pub use kitsune_p2p;
 #[async_trait::async_trait]
 /// A wrapper around HolochainP2pSender that partially applies the dna_hash / agent_pub_key.
 /// I.e. a sender that is tied to a specific cell.
-pub trait HolochainP2pCellT {
+pub trait HolochainP2pDnaT {
     /// owned getter
     fn dna_hash(&self) -> DnaHash;
 
-    /// owned getter
-    fn from_agent(&self) -> AgentPubKey;
-
-    /// Construct the CellId from the defined DnaHash and AgentPubKey
-    fn cell_id(&self) -> CellId {
-        CellId::new(self.dna_hash(), self.from_agent())
-    }
-
     /// The p2p module must be informed at runtime which dna/agent pairs it should be tracking.
-    async fn join(&self) -> actor::HolochainP2pResult<()>;
+    async fn join(&self, agent: AgentPubKey) -> actor::HolochainP2pResult<()>;
 
     /// If a cell is disabled, we'll need to \"leave\" the network module as well.
-    async fn leave(&self) -> actor::HolochainP2pResult<()>;
+    async fn leave(&self, agent: AgentPubKey) -> actor::HolochainP2pResult<()>;
 
     /// Invoke a zome function on a remote node (if you have been granted the capability).
     async fn call_remote(
         &self,
+        from_agent: AgentPubKey,
         to_agent: AgentPubKey,
         zome_name: ZomeName,
         fn_name: FunctionName,
@@ -59,6 +52,7 @@ pub trait HolochainP2pCellT {
     /// it may decide not to deliver some of the signals.
     async fn remote_signal(
         &self,
+        from_agent: AgentPubKey,
         to_agent_list: Vec<AgentPubKey>,
         zome_name: ZomeName,
         fn_name: FunctionName,
@@ -141,41 +135,32 @@ pub trait HolochainP2pCellT {
 /// A wrapper around HolochainP2pSender that partially applies the dna_hash / agent_pub_key.
 /// I.e. a sender that is tied to a specific cell.
 #[derive(Clone)]
-pub struct HolochainP2pCell {
+pub struct HolochainP2pDna {
     sender: ghost_actor::GhostSender<actor::HolochainP2p>,
     dna_hash: Arc<DnaHash>,
-    from_agent: Arc<AgentPubKey>,
 }
 
 #[async_trait::async_trait]
-impl HolochainP2pCellT for HolochainP2pCell {
+impl HolochainP2pDnaT for HolochainP2pDna {
     /// owned getter
     fn dna_hash(&self) -> DnaHash {
         (*self.dna_hash).clone()
     }
 
-    /// owned getter
-    fn from_agent(&self) -> AgentPubKey {
-        (*self.from_agent).clone()
-    }
-
     /// The p2p module must be informed at runtime which dna/agent pairs it should be tracking.
-    async fn join(&self) -> actor::HolochainP2pResult<()> {
-        self.sender
-            .join((*self.dna_hash).clone(), (*self.from_agent).clone())
-            .await
+    async fn join(&self, agent: AgentPubKey) -> actor::HolochainP2pResult<()> {
+        self.sender.join((*self.dna_hash).clone(), agent).await
     }
 
     /// If a cell is disabled, we'll need to \"leave\" the network module as well.
-    async fn leave(&self) -> actor::HolochainP2pResult<()> {
-        self.sender
-            .leave((*self.dna_hash).clone(), (*self.from_agent).clone())
-            .await
+    async fn leave(&self, agent: AgentPubKey) -> actor::HolochainP2pResult<()> {
+        self.sender.leave((*self.dna_hash).clone(), agent).await
     }
 
     /// Invoke a zome function on a remote node (if you have been granted the capability).
     async fn call_remote(
         &self,
+        from_agent: AgentPubKey,
         to_agent: AgentPubKey,
         zome_name: ZomeName,
         fn_name: FunctionName,
@@ -185,7 +170,7 @@ impl HolochainP2pCellT for HolochainP2pCell {
         self.sender
             .call_remote(
                 (*self.dna_hash).clone(),
-                (*self.from_agent).clone(),
+                from_agent,
                 to_agent,
                 zome_name,
                 fn_name,
@@ -201,6 +186,7 @@ impl HolochainP2pCellT for HolochainP2pCell {
     /// it may decide not to deliver some of the signals.
     async fn remote_signal(
         &self,
+        from_agent: AgentPubKey,
         to_agent_list: Vec<AgentPubKey>,
         zome_name: ZomeName,
         fn_name: FunctionName,
@@ -210,7 +196,7 @@ impl HolochainP2pCellT for HolochainP2pCell {
         self.sender
             .remote_signal(
                 (*self.dna_hash).clone(),
-                (*self.from_agent).clone(),
+                from_agent,
                 to_agent_list,
                 zome_name,
                 fn_name,
@@ -232,7 +218,6 @@ impl HolochainP2pCellT for HolochainP2pCell {
         self.sender
             .publish(
                 (*self.dna_hash).clone(),
-                (*self.from_agent).clone(),
                 request_validation_receipt,
                 countersigning_session,
                 dht_hash,
@@ -251,7 +236,6 @@ impl HolochainP2pCellT for HolochainP2pCell {
         self.sender
             .get_validation_package(actor::GetValidationPackage {
                 dna_hash: (*self.dna_hash).clone(),
-                agent_pub_key: (*self.from_agent).clone(),
                 request_from,
                 header_hash,
             })
@@ -265,12 +249,7 @@ impl HolochainP2pCellT for HolochainP2pCell {
         options: actor::GetOptions,
     ) -> actor::HolochainP2pResult<Vec<WireOps>> {
         self.sender
-            .get(
-                (*self.dna_hash).clone(),
-                (*self.from_agent).clone(),
-                dht_hash,
-                options,
-            )
+            .get((*self.dna_hash).clone(), dht_hash, options)
             .instrument(tracing::debug_span!("HolochainP2p::get"))
             .await
     }
@@ -282,12 +261,7 @@ impl HolochainP2pCellT for HolochainP2pCell {
         options: actor::GetMetaOptions,
     ) -> actor::HolochainP2pResult<Vec<MetadataSet>> {
         self.sender
-            .get_meta(
-                (*self.dna_hash).clone(),
-                (*self.from_agent).clone(),
-                dht_hash,
-                options,
-            )
+            .get_meta((*self.dna_hash).clone(), dht_hash, options)
             .await
     }
 
@@ -298,12 +272,7 @@ impl HolochainP2pCellT for HolochainP2pCell {
         options: actor::GetLinksOptions,
     ) -> actor::HolochainP2pResult<Vec<WireLinkOps>> {
         self.sender
-            .get_links(
-                (*self.dna_hash).clone(),
-                (*self.from_agent).clone(),
-                link_key,
-                options,
-            )
+            .get_links((*self.dna_hash).clone(), link_key, options)
             .await
     }
 
@@ -315,13 +284,7 @@ impl HolochainP2pCellT for HolochainP2pCell {
         options: actor::GetActivityOptions,
     ) -> actor::HolochainP2pResult<Vec<AgentActivityResponse<HeaderHash>>> {
         self.sender
-            .get_agent_activity(
-                (*self.dna_hash).clone(),
-                (*self.from_agent).clone(),
-                agent,
-                query,
-                options,
-            )
+            .get_agent_activity((*self.dna_hash).clone(), agent, query, options)
             .await
     }
 
@@ -332,12 +295,7 @@ impl HolochainP2pCellT for HolochainP2pCell {
         receipt: SerializedBytes,
     ) -> actor::HolochainP2pResult<()> {
         self.sender
-            .send_validation_receipt(
-                (*self.dna_hash).clone(),
-                to_agent,
-                (*self.from_agent).clone(),
-                receipt,
-            )
+            .send_validation_receipt((*self.dna_hash).clone(), to_agent, receipt)
             .await
     }
 
@@ -347,11 +305,7 @@ impl HolochainP2pCellT for HolochainP2pCell {
         dht_hash: holo_hash::AnyDhtHash,
     ) -> actor::HolochainP2pResult<bool> {
         self.sender
-            .authority_for_hash(
-                (*self.dna_hash).clone(),
-                (*self.from_agent).clone(),
-                dht_hash,
-            )
+            .authority_for_hash((*self.dna_hash).clone(), dht_hash)
             .await
     }
 
@@ -361,12 +315,7 @@ impl HolochainP2pCellT for HolochainP2pCell {
         response: Vec<SignedHeader>,
     ) -> actor::HolochainP2pResult<()> {
         self.sender
-            .countersigning_authority_response(
-                (*self.dna_hash).clone(),
-                (*self.from_agent).clone(),
-                agents,
-                response,
-            )
+            .countersigning_authority_response((*self.dna_hash).clone(), agents, response)
             .await
     }
 
