@@ -176,6 +176,7 @@ mod tests {
     use ::fixt::prelude::*;
     use futures::future::FutureExt;
     use ghost_actor::GhostControlSender;
+    use kitsune_p2p::dht_arc::PeerStratBeta;
 
     use crate::HolochainP2pSender;
     use holochain_zome_types::ValidationStatus;
@@ -232,6 +233,15 @@ mod tests {
                     PutAgentInfoSigned { respond, .. } => {
                         respond.r(Ok(async move { Ok(()) }.boxed().into()));
                     }
+                    QueryPeerDensity { respond, .. } => {
+                        let view = kitsune_p2p_types::dht_arc::PeerViewBeta::new(
+                            PeerStratBeta::default(),
+                            dht_arc::DhtArc::full(0),
+                            1.0,
+                            2,
+                        );
+                        respond.r(Ok(async move { Ok(view) }.boxed().into()));
+                    }
                     _ => {}
                 }
             }
@@ -289,6 +299,15 @@ mod tests {
                     PutAgentInfoSigned { respond, .. } => {
                         respond.r(Ok(async move { Ok(()) }.boxed().into()));
                     }
+                    QueryPeerDensity { respond, .. } => {
+                        let view = kitsune_p2p_types::dht_arc::PeerViewBeta::new(
+                            PeerStratBeta::default(),
+                            dht_arc::DhtArc::full(0),
+                            1.0,
+                            2,
+                        );
+                        respond.r(Ok(async move { Ok(view) }.boxed().into()));
+                    }
                     _ => {}
                 }
             }
@@ -337,6 +356,15 @@ mod tests {
                     QueryAgentInfoSigned { respond, .. } => {
                         respond.r(Ok(async move { Ok(vec![]) }.boxed().into()));
                     }
+                    QueryPeerDensity { respond, .. } => {
+                        let view = kitsune_p2p_types::dht_arc::PeerViewBeta::new(
+                            PeerStratBeta::default(),
+                            dht_arc::DhtArc::full(0),
+                            1.0,
+                            2,
+                        );
+                        respond.r(Ok(async move { Ok(view) }.boxed().into()));
+                    }
                     _ => {}
                 }
             }
@@ -369,12 +397,15 @@ mod tests {
 
         let (dna, a1, a2, _a3) = test_setup();
 
-        let (p2p, mut evt) = spawn_holochain_p2p(
-            KitsuneP2pConfig::default(),
-            TlsConfig::new_ephemeral().await.unwrap(),
-        )
-        .await
-        .unwrap();
+        let cert = TlsConfig::new_ephemeral().await.unwrap();
+
+        let mut params =
+            kitsune_p2p_types::config::tuning_params_struct::KitsuneP2pTuningParams::default();
+        params.default_rpc_multi_remote_agent_count = 1;
+        params.default_rpc_multi_remote_request_grace_ms = 100;
+        let mut config = KitsuneP2pConfig::default();
+        config.tuning_params = Arc::new(params);
+        let (p2p, mut evt) = spawn_holochain_p2p(config, cert).await.unwrap();
 
         let test_1 = WireOps::Element(WireElementOps {
             header: Some(Judged::valid(SignedHeader(fixt!(Header), fixt!(Signature)))),
@@ -416,7 +447,16 @@ mod tests {
                     QueryOpHashes { respond, .. } => {
                         respond.r(Ok(async move { Ok(None) }.boxed().into()));
                     }
-                    evt => println!("unhandled: {:?}", evt),
+                    QueryPeerDensity { respond, .. } => {
+                        let view = kitsune_p2p_types::dht_arc::PeerViewBeta::new(
+                            PeerStratBeta::default(),
+                            dht_arc::DhtArc::full(0),
+                            1.0,
+                            2,
+                        );
+                        respond.r(Ok(async move { Ok(view) }.boxed().into()));
+                    }
+                    evt => tracing::trace!("unhandled: {:?}", evt),
                 }
             }
         });
@@ -455,12 +495,16 @@ mod tests {
     async fn test_get_links_workflow() {
         let (dna, a1, a2, _) = test_setup();
 
-        let (p2p, mut evt) = spawn_holochain_p2p(
-            KitsuneP2pConfig::default(),
-            TlsConfig::new_ephemeral().await.unwrap(),
-        )
-        .await
-        .unwrap();
+        let mut params =
+            kitsune_p2p_types::config::tuning_params_struct::KitsuneP2pTuningParams::default();
+        params.default_rpc_multi_remote_agent_count = 1;
+        params.default_rpc_multi_remote_request_grace_ms = 100;
+        let mut config = KitsuneP2pConfig::default();
+        config.tuning_params = Arc::new(params);
+
+        let (p2p, mut evt) = spawn_holochain_p2p(config, TlsConfig::new_ephemeral().await.unwrap())
+            .await
+            .unwrap();
 
         let test_1 = WireLinkOps {
             creates: vec![WireCreateLink::condense(
@@ -491,6 +535,15 @@ mod tests {
                     PutAgentInfoSigned { respond, .. } => {
                         respond.r(Ok(async move { Ok(()) }.boxed().into()));
                     }
+                    QueryPeerDensity { respond, .. } => {
+                        let view = kitsune_p2p_types::dht_arc::PeerViewBeta::new(
+                            PeerStratBeta::default(),
+                            dht_arc::DhtArc::full(0),
+                            1.0,
+                            2,
+                        );
+                        respond.r(Ok(async move { Ok(view) }.boxed().into()));
+                    }
                     _ => {}
                 }
             }
