@@ -128,7 +128,7 @@ impl Default for GetMetaOptions {
     }
 }
 
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Default)]
 /// Get links from the DHT.
 /// Fields tagged with `[Network]` are network-level controls.
 /// Fields tagged with `[Remote]` are controls that will be forwarded to the
@@ -142,12 +142,6 @@ pub struct GetLinksOptions {
     pub timeout_ms: Option<u64>,
 }
 
-impl Default for GetLinksOptions {
-    fn default() -> Self {
-        Self { timeout_ms: None }
-    }
-}
-
 #[derive(Debug, Clone)]
 /// Get agent activity from the DHT.
 /// Fields tagged with `[Network]` are network-level controls.
